//+------------------------------------------------------------------+
//|                                                    WPR_delta.mq4 |
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+
#property link      ""

#define MAGICP            20091209

#define SIGNAL_UP         0
#define SIGNAL_DOWN       1
#define UNKNOWN           2

#define SLIPPAGE          50

//---- input parameters
extern double     wpr_up_level = -1;
extern double     wpr_down_level = -99;
extern int        period_wpr = 7;
extern int        count_wpr = 1;

extern double     tp = 3000;
extern double     sl = 3000;
extern int        TrailingStop = 1000;

int signal = UNKNOWN;
int current_state = -1;
//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{ 
   signal=CheckSignal();
   if(signal==SIGNAL_DOWN)
      current_state=OP_SELL;
   else if(signal==SIGNAL_UP)
      current_state=OP_BUY;
      
   CheckForClose();
   CheckForOpen();

   return(0);
}
//+------------------------------------------------------------------+
int CountOpen(int cmd)
{
   int count=0;
   for(int i=0;i<OrdersTotal();i++)
   {
      if(OrderSelect(i,SELECT_BY_POS))
      {
         if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICP && OrderType()==cmd)
            count++;
      }
   }
   return (count);
}
//+------------------------------------------------------------------+
// Check for open order conditions
void CheckForOpen()
{
   static datetime OpenTime=0;
   if(OpenTime==Time[0])return;//check open new bar
  
   double lot_otimized;
   if(signal==SIGNAL_DOWN)//sell conditions
   {
      //lot_otimized=MathPow(2,CountOpen(OP_BUY))*MarketInfo(Symbol(),MODE_MINLOT);
      lot_otimized=/*(MathFloor(MathLog(CountOpen(OP_BUY)+1))+1)**/MarketInfo(Symbol(),MODE_MINLOT);
      if(lot_otimized>MarketInfo(Symbol(),MODE_MAXLOT))lot_otimized=MarketInfo(Symbol(),MODE_MAXLOT);
      if(AccountFreeMargin()>lot_otimized*MarketInfo(Symbol(),MODE_MARGINREQUIRED))//check for margin
      {
         if(OrderSend(Symbol(),OP_SELL,lot_otimized,Bid,SLIPPAGE,Ask+sl*Point,Bid-tp*Point,NULL,MAGICP,0,Red)>=0)
            OpenTime=Time[0];
      }
      return;
   }
   else if(signal==SIGNAL_UP)//buy conditions
   {
      //lot_otimized=MathPow(2,CountOpen(OP_BUY))*MarketInfo(Symbol(),MODE_MINLOT);
      lot_otimized=/*(MathFloor(MathLog(CountOpen(OP_BUY)+1))+1)**/MarketInfo(Symbol(),MODE_MINLOT);
      if(lot_otimized>MarketInfo(Symbol(),MODE_MAXLOT))lot_otimized=MarketInfo(Symbol(),MODE_MAXLOT);
      if(AccountFreeMargin()>lot_otimized*MarketInfo(Symbol(),MODE_MARGINREQUIRED))//check for margin
      {
         if(OrderSend(Symbol(),OP_BUY,lot_otimized,Ask,SLIPPAGE,Bid-sl*Point,Bid+tp*Point,NULL,MAGICP,0,Blue)>=0)
            OpenTime=Time[0];
      }
      return;
   }
}
// Check for close order conditions
void CheckForClose()
{
   int totalOrders=OrdersTotal();
   for(int i=0;i<totalOrders;i++)
   {
      if(OrderSelect(i,SELECT_BY_POS))
      {
         if(OrderMagicNumber()==MAGICP && OrderSymbol()==Symbol())
         {
            //check order type 
            if(OrderType()==OP_BUY)
            {
               if(current_state==OP_SELL)
                  OrderClose(OrderTicket(),OrderLots(),Bid,SLIPPAGE,White);
            }
            if(OrderType()==OP_SELL)
            {
               if(current_state==OP_BUY)
                  OrderClose(OrderTicket(),OrderLots(),Ask,SLIPPAGE,White);
            }
         }
      }
   }
}
//+------------------------------------------------------------------+
//| Check state                                                      |
//+------------------------------------------------------------------+
int CheckSignal()
{
   double wpr[];
   ArrayResize(wpr,count_wpr);
   for(int i=0;i<count_wpr;i++)
      wpr[i]=iWPR(Symbol(),0,(i+1)*period_wpr,0);
   
   double wpr_max=wpr[ArrayMaximum(wpr)],wpr_min=wpr[ArrayMinimum(wpr)];
    
   if(wpr_min>wpr_up_level)
      return (SIGNAL_DOWN);
   else if(wpr_max<wpr_down_level) 
      return (SIGNAL_UP);
   else
      return (UNKNOWN);
}
//+------------------------------------------------------------------+